@@ -40,13 +40,14 @@ import           Control.Applicative    as Ap
 import           Control.Monad.Identity (runIdentity)
 import           Data.Aeson             as J
 #if MIN_VERSION_aeson(2,0,0)
-import qualified Data.Aeson.Key                as AK
-import qualified Data.Aeson.KeyMap             as AKM
+import qualified Data.Aeson.Key         as AK
+import qualified Data.Aeson.KeyMap      as AKM
+#else
+import qualified Data.HashMap.Strict    as HM
 #endif
 import qualified Data.Aeson.Types       as J
 import qualified Data.ByteString        as BS
 import qualified Data.ByteString.Lazy   as BS.L
-import qualified Data.HashMap.Strict    as HM
 import qualified Data.Map               as Map
 import           Data.Scientific
 import           Data.Text              (Text)
@@ -173,7 +174,7 @@ decodeValue' SchemaResolver{..} keyconv bs0
 #if MIN_VERSION_aeson(2,0,0)
     fT = AK.fromText
 #else
-    fT = id   
+    fT = id
 #endif
 
     mkArr :: [J.Value] -> Either (Pos, String) J.Value
@@ -201,11 +202,7 @@ scalarToValue (SUnknown _ _) = Nothing
 -- O(n) Convert a lazy ByteString into a strict ByteString.
 {-# INLINE bsToStrict #-}
 bsToStrict :: BS.L.ByteString -> BS.ByteString
-#if MIN_VERSION_bytestring(0,10,0)
 bsToStrict = BS.L.toStrict
-#else
-bsToStrict = BS.concat . BS.L.toChunks
-#endif
 
 -- | @since 0.2.0
 instance ToYAML J.Value where
